@@ -47,7 +47,7 @@ from data_science_helper.model import lgb_model as l
 #import model.scale_pos_weight__lgb_model as spw_lgb_model
 #import model.custom_bagging__lgb_model as cb_lgb_model
 
-def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric='average_precision',num_rounds=10000,early_stop=400,log=0,api="train_api",random_state=42,url=None,print_consola=True):
+def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,enable_umbral_opt=False,metric='average_precision',num_rounds=10000,early_stop=400,log=0,api="train_api",random_state=42,url=None,print_consola=True):
     start = time.time()
         
     params.update({"metric":metric})
@@ -59,7 +59,7 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
             "url":url }     
     
 
-    model , y_prob_uno   = l.modelar(**args)
+    model ,  y_prob_uno_train, y_prob_uno_test    = l.modelar(**args)
     '''
     if (strategy=="neg_bagging_fraction__lgb_model"):
         model , y_prob_uno   = l.modelar(**args)
@@ -68,14 +68,21 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
     if (strategy=="custom_bagging__lgb_model"):
         model , y_prob_uno   = cb_lgb_model.modelar(X_train,y_train,X_test,y_test,url)
     '''    
-    umbral_opt = g.get_opt_threshold(y_test,y_prob_uno)
+   
+    
+    kpis_train = generar_reporte(model,y_prob_uno_train,X_train,y_train,None,url,print_consola)
 
-    kpis = generar_reporte(model,y_prob_uno,X_test,y_test,None,url,print_consola)
-    kpis_opt = generar_reporte(model,y_prob_uno,X_test,y_test,umbral_opt,url,print_consola)
+    kpis_test = generar_reporte(model,y_prob_uno_test,X_test,y_test,None,url,print_consola)
+    umbral_opt=0
+    kpis_opt = (0,0,0,0)
+    
+    if enable_umbral_opt:
+        umbral_opt = g.get_opt_threshold(y_test,y_prob_uno_test)   
+        kpis_opt = generar_reporte(model,y_prob_uno_test,X_test,y_test,umbral_opt,url,print_consola)
     
     print("Time elapsed: ", time.time() - start)
     
-    return model , y_prob_uno  , kpis , kpis_opt , umbral_opt
+    return model ,  kpis_train, kpis_test , kpis_opt , umbral_opt
 
 
 def modelar_clasificacion_binaria_rscv(strategy, X_train,y_train=None,X_test=None,y_test=None,score_rs=None,params=None,param_dist=None, n_iter=None,n_jobs=None,url=None,print_consola=True):
@@ -134,7 +141,7 @@ def predecir_clasificacion_binaria(model, X=None, umbral=0.5):
 
 
 def get_result_df(KPIs_list):
-    df = pd.DataFrame(columns=["Macro Región","Modelo","T Train","T Train Class 1","T Test","T Test Class 1",'Precision', 'Recall', 'F1','Average Precision','ROC AUC',"umbral_opt",'Precision_opt', 'Recall_opt', 'F1_opt','Average Precision opt','ROC AUC opt'])
+    df = pd.DataFrame(columns=["Macro Región","Modelo","T Train","T Train Class 1","T Test","T Test Class 1",'Precision Train', 'Recall Train', 'F1 Train','Average Precision Train','ROC AUC Train', 'Precision Test', 'Recall Test', 'F1 Test','Average Precision Test','ROC AUC Test',"umbral_opt",'Precision_opt', 'Recall_opt', 'F1_opt','Average Precision opt','ROC AUC opt'])
     for idx, result  in enumerate(KPIs_list):
         mr = result[0]
         
@@ -148,10 +155,13 @@ def get_result_df(KPIs_list):
         
         t_test_class_1 = result[5]
         
-        Ks = result[6]
-        umbral_opt = result[7]
-        Ks_opt = result[8]
-        result_rd = [mr,mod,t_train,t_train_class_1,t_test,t_test_class_1]+[round(num, 3) for num in list(Ks)]+[umbral_opt]+[round(num_opt, 3) for num_opt in list(Ks_opt)]
+        Ks_train = result[6]
+        
+        Ks = result[7]
+        umbral_opt = result[8]
+        Ks_opt = result[9]
+        
+        result_rd = [mr,mod,t_train,t_train_class_1,t_test,t_test_class_1]+[round(num, 3) for num in list(Ks_train)]+[round(num, 3) for num in list(Ks)]+[umbral_opt]+[round(num_opt, 3) for num_opt in list(Ks_opt)]
         df.loc[idx] = result_rd
 
         #df.loc[i] = list(KPIs)
