@@ -172,12 +172,17 @@ def modelar(X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric
     if api=="train_api":
 
         model = lgb_model_train(X_train,y_train,X_test,y_test,params=params,metric=metric,num_rounds=num_rounds,early_stop=early_stop,log=log)
-        y_prob_uno = model.predict(X_test, num_iteration=model.best_iteration) 
+        y_prob_uno_train = model.predict(X_train, num_iteration=model.best_iteration) 
+        y_prob_uno_test  = model.predict(X_test, num_iteration=model.best_iteration) 
         
     elif api=="skl_api":
-        model = lgb_model_skl(X_train,y_train,X_test,y_test,params=params,metric=metric)        
-        predicted_probas = model.predict_proba(X_test) 
-        y_prob_uno = predicted_probas[:,1]
+        model = lgb_model_skl(X_train,y_train,X_test,y_test,params=params,metric=metric)  
+        
+        predicted_probas_train = model.predict_proba(X_test) 
+        y_prob_uno_train = predicted_probas_train[:,1]
+        
+        predicted_probas_test = model.predict_proba(X_test) 
+        y_prob_uno_test = predicted_probas_test[:,1]
         
     if url is not None:
         g.save_model(model,url)
@@ -187,7 +192,7 @@ def modelar(X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric
     if model is None:
         raise Exception("Modelo no implementado")
     
-    return model , y_prob_uno 
+    return model , y_prob_uno_train, y_prob_uno_test 
 
 
 def lgb_model_skl(X_train,y_train,X_test,y_test,metric='average_precision',params=None):
